@@ -1,11 +1,12 @@
-use std::convert::TryFrom;
-use std::fmt;
-use std::fmt::{Display, Formatter};
-use std::slice::Iter;
+use std::{
+    convert::TryFrom,
+    fmt,
+    fmt::{Display, Formatter},
+    slice::Iter,
+    vec::IntoIter,
+};
 
-use crate::body::Body;
-use crate::fragment::Fragment;
-use crate::trailer::Trailer;
+use crate::{body::Body, fragment::Fragment, trailer::Trailer};
 
 /// A collection of user input `CommitMessage` text
 #[derive(Debug, PartialEq, Clone)]
@@ -41,8 +42,7 @@ impl Bodies {
     /// # Examples
     ///
     /// ```
-    /// use mit_commit::Bodies;
-    /// use mit_commit::Body;
+    /// use mit_commit::{Bodies, Body};
     /// let trailers = Bodies::from(vec![
     ///     Body::from("Body 1"),
     ///     Body::from("Body 2"),
@@ -61,6 +61,33 @@ impl Bodies {
     }
 }
 
+impl IntoIterator for Bodies {
+    type IntoIter = IntoIter<Body>;
+    type Item = Body;
+
+    /// Iterate over the `Body` in the `Bodies`
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use mit_commit::{Bodies, Body};
+    /// let trailers = Bodies::from(vec![
+    ///     Body::from("Body 1"),
+    ///     Body::from("Body 2"),
+    ///     Body::from("Body 3"),
+    /// ]);
+    /// let mut iterator = trailers.into_iter();
+    ///
+    /// assert_eq!(iterator.next(), Some(Body::from("Body 1")));
+    /// assert_eq!(iterator.next(), Some(Body::from("Body 2")));
+    /// assert_eq!(iterator.next(), Some(Body::from("Body 3")));
+    /// assert_eq!(iterator.next(), None);
+    /// ```
+    fn into_iter(self) -> Self::IntoIter {
+        self.bodies.into_iter()
+    }
+}
+
 impl Display for Bodies {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         write!(f, "{}", String::from(self.clone()))
@@ -119,14 +146,10 @@ impl From<Vec<Fragment>> for Bodies {
 
 #[cfg(test)]
 mod tests {
-    use pretty_assertions::assert_eq;
-
     use indoc::indoc;
 
-    use crate::body::Body;
-    use crate::fragment::Fragment;
-
     use super::Bodies;
+    use crate::{body::Body, fragment::Fragment};
 
     #[test]
     fn implements_iterator() {
