@@ -1,5 +1,7 @@
-use std::fmt;
-use std::fmt::{Display, Formatter};
+use std::{
+    fmt,
+    fmt::{Display, Formatter},
+};
 
 /// A single contiguous block of `CommitMessage` text
 #[derive(Debug, PartialEq, Clone, Default)]
@@ -34,8 +36,8 @@ impl Body {
 
     /// Is this body empty
     ///
-    /// Empty bodies usually indicate a paragraph break in commit messages so it's handy to be able
-    /// to see them.
+    /// Empty bodies usually indicate a paragraph break in commit messages so
+    /// it's handy to be able to see them.
     ///
     /// # Example
     ///
@@ -79,8 +81,6 @@ impl Display for Body {
 
 #[cfg(test)]
 mod tests {
-    use pretty_assertions::assert_eq;
-
     use indoc::indoc;
 
     use super::Body;
@@ -120,11 +120,11 @@ mod tests {
 
     #[test]
     fn it_can_tell_me_if_it_is_empty() {
-        assert_eq!(Body::from("").is_empty(), true);
+        assert!(Body::from("").is_empty());
     }
 
     #[test]
     fn it_can_tell_me_if_it_is_full() {
-        assert_eq!(Body::from("something").is_empty(), false);
+        assert!(!Body::from("something").is_empty());
     }
 }
